@@ -3,6 +3,7 @@ from __future__ import annotations
 import json
 import logging
 import re
+from datetime import datetime
 from time import time
 from typing import Any
 from typing import cast
@@ -56,9 +57,52 @@ class NextBusClient:
         agency_id: str | None = None,
     ) -> None:
         self.agency_id: str | None = agency_id
-        self.headers: dict[str, str] = {
-            "Accept": "application/json, text/javascript, */*; q=0.01",
-        }
+
+        self._session: requests.Session = requests.Session()
+        self._session.headers.update(
+            {
+                "User-Agent": "PyNextBus",
+                "Accept": "application/json",
+                "Accept-Language": "en-US,en;q=0.5",
+                "Accept-Encoding": "gzip, deflate, br, zstd",
+                "Compress": "true",
+                "DNT": "1",
+                "Sec-Fetch-Dest": "empty",
+                "Sec-Fetch-Mode": "cors",
+                "Connection": "keep-alive",
+                # Additional headers used in browser
+                # "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:138.0) Gecko/20100101 Firefox/138.0",
+                # "Referer": "https://rider.umoiq.com/",
+                # "Origin": "https://rider.umoiq.com",
+            }
+        )
+
+        self._rate_limit: int = 0
+        self._rate_limit_remaining: int = 0
+        self._rate_limit_reset: datetime | None = None
+
+    @property
+    def rate_limit(self) -> int:
+        """Returns the rate limit for the API."""
+        return self._rate_limit
+
+    @property
+    def rate_limit_remaining(self) -> int:
+        """Returns the remaining rate limit for the API."""
+        return self._rate_limit_remaining
+
+    @property
+    def rate_limit_reset(self) -> datetime | None:
+        """Returns the time when the rate limit will reset."""
+        return self._rate_limit_reset
+
+    @property
+    def rate_limit_percent(self) -> float:
+        """Returns the percentage of the rate limit remaining."""
+        if self.rate_limit == 0:
+            return 0.0
+
+        return self.rate_limit_remaining / self.rate_limit * 100
 
     def agencies(self) -> list[dict[str, Any]]:
         result = self._get("agencies")
@@ -141,9 +185,21 @@ class NextBusClient:
         try:
             url = f"{self.base_url}/{endpoint}"
             LOG.debug("GET %s", url)
-            response = requests.get(url, params=params, headers=self.headers)
+            response = self._session.get(url, params=params)
             response.raise_for_status()
+
+            # Track rate limit information
+            self._rate_limit = int(response.headers.get("X-RateLimit-Limit", 0))
+            self._rate_limit_remaining = int(
+                response.headers.get("X-RateLimit-Remaining", 0)
+            )
+            reset_time = response.headers.get("X-RateLimit-Reset")
+            self._rate_limit_reset = (
+                datetime.fromtimestamp(int(reset_time)) if reset_time else None
+            )
+
             return response.json()
+
         except HTTPError as exc:
             raise NextBusHTTPError("Error from the NextBus API", exc) from exc
         except json.decoder.JSONDecodeError as exc:
